aboutsummaryrefslogtreecommitdiff
path: root/src/google/protobuf/testing/googletest.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/google/protobuf/testing/googletest.h')
-rw-r--r--src/google/protobuf/testing/googletest.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/google/protobuf/testing/googletest.h b/src/google/protobuf/testing/googletest.h
index 9420641a..bb4aafab 100644
--- a/src/google/protobuf/testing/googletest.h
+++ b/src/google/protobuf/testing/googletest.h
@@ -33,10 +33,12 @@ string TestSourceDir();
// placed.
string TestTempDir();
-// Capture all text written to stderr.
+// Capture all text written to stdout or stderr.
+void CaptureTestStdout();
void CaptureTestStderr();
-// Stop capturing stderr and return the text captured.
+// Stop capturing stdout or stderr and return the text captured.
+string GetCapturedTestStdout();
string GetCapturedTestStderr();
// For use with ScopedMemoryLog::GetMessages(). Inside Google the LogLevel